Module signal

Module signal 

Enums

Error

Traits

Killable
Trait for threads that can be signalled via pthread_kill.

Functions

SIGRTMAX
Returns the maximum (inclusive) real-time signal number.
SIGRTMIN
Returns the minimum (inclusive) real-time signal number.
block_signal
Masks given signal.
clear_signal
Clears pending signal.
create_sigset
Creates sigset from an array of signal numbers.
get_blocked_signals
Retrieves the signal mask of the current thread as a vector of c_ints.
register_signal_handler
Registers handler as the signal handler of signum num.
unblock_signal
Unmasks given signal.

Type Aliases

SignalResult