IntoIovec

Trait IntoIovec 

pub unsafe trait IntoIovec {
    // Required methods
    fn as_ptr(&self) -> *const c_void;
    fn size(&self) -> usize;
}
Trait for types that can be converted into an iovec that can be referenced by a syscall for the lifetime of this object.

This trait is unsafe because interfaces that use this trait depend on the base pointer and size being accurate.

Required Methods

fn as_ptr(&self) -> *const c_void

Gets the base pointer of this iovec.

fn size(&self) -> usize

Gets the size in bytes of this iovec.

Implementations on Foreign Types

Source

impl<'a> IntoIovec for &'a [u8]

Source

impl<'a> IntoIovec for VolatileSlice<'a>

Implementors