pub unsafe trait IntoIovec {
// Required methods
fn as_ptr(&self) -> *const c_void;
fn size(&self) -> usize;
}Expand description
Trait for types that can be converted into an iovec that can be referenced by a syscall for
the lifetime of this object.
This trait is unsafe because interfaces that use this trait depend on the base pointer and size being accurate.